:orphan:

.. _services:

**************************************************
Services 
**************************************************

Monitoring
-------------

The FlexMeasures platform continuously reads in meter data from your assets. To assist your maintenance, it can alert you to situations which need your attention:

* Breaches of thresholds (protect devices)
* Data gaps & strange outliers (assure data quality)
* Idle processes / leaks (minimise waste)

.. todo:: These features are work in progress. Most of our customers already do this by themselves in a straightforward manner.


Forecasting
--------------

The FlexMeasures platform continuously creates forecasts for the rest of day.

All relevant data should be forecasted:

* Energy assets
* Weather data
* Market prices


Scheduling
--------------

The FlexMeasures platform optimises schedules for your flexible assets. This is where energy flexibility is valorised!

Examples are:

* Charging schedules of batteries
* Heat pumps management
* Buffering of machinery

The goals can be maximal cost savings, maximal usage of solar power or stable energy supply for the most crucial consumers.
